PairingError

Enum PairingError 

#[non_exhaustive]
pub enum PairingError {
Show 16 variants EmptyTransportUri, InvalidContactMessage(&'static str), InvalidPairRequestMessage(&'static str), InvalidPairResponseMessage(&'static str), NonOkStatus { status: i32, memo: String, }, ProtocolViolation(&'static str), PrePairHashMismatch, MissingReplicaId { sender_kind: SenderKind, }, UnexpectedReplicaId { sender_kind: SenderKind, }, IncompatibleParameterRange { field: &'static str, local_min: i64, local_max: i64, peer_min: i64, peer_max: i64, }, Invariant(&'static str), ContactMessageKeygen { source: DerecPairingError, }, PairRequestKeygen { source: DerecPairingError, }, FinishPairingInitiator { source: DerecPairingError, }, FinishPairingResponder { source: DerecPairingError, }, PairingEncryption(DerecEncryptionError),
}

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyTransportUri



InvalidContactMessage(&'static str)



InvalidPairRequestMessage(&'static str)



InvalidPairResponseMessage(&'static str)



NonOkStatus

Fields

status: i32
memo: String


ProtocolViolation(&'static str)



PrePairHashMismatch



MissingReplicaId

Fields

sender_kind: SenderKind


UnexpectedReplicaId

Fields

sender_kind: SenderKind


IncompatibleParameterRange

The peer’s advertised ParameterRange does not overlap the local one on field. local and peer are the offending (min, max) pair so the application can render a useful diagnostic.

Fields

field: &'static str
local_min: i64
local_max: i64
peer_min: i64
peer_max: i64


Invariant(&'static str)



ContactMessageKeygen

Fields



PairRequestKeygen

Fields



FinishPairingInitiator

Fields



FinishPairingResponder

Fields



PairingEncryption(DerecEncryptionError)