#[non_exhaustive]pub enum Error {
Show 20 variants
Pairing(PairingError),
Recovery(RecoveryError),
Discovery(DiscoveryError),
Sharing(SharingError),
Verification(VerificationError),
Unpairing(UnpairingError),
Restore(RestoreError),
DeRecMessage(DeRecMessageBuilderError),
SecretStore(SecretStoreError),
ChannelStore(ChannelStoreError),
ShareStore(ShareStoreError),
StateStore(StateStoreError),
Transport(TransportValidationError),
InvalidInput(&'static str),
ProtobufDecode(DecodeError),
ProtobufEncode(EncodeError),
Invariant(&'static str),
RoleMismatch {
channel_id: ChannelId,
expected: SenderKind,
actual: SenderKind,
},
ChannelAlreadyPaired {
channel_id: ChannelId,
},
ReplicaIdNotConfigured,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pairing(PairingError)
Recovery(RecoveryError)
Discovery(DiscoveryError)
Sharing(SharingError)
Verification(VerificationError)
Unpairing(UnpairingError)
Restore(RestoreError)
DeRecMessage(DeRecMessageBuilderError)
SecretStore(SecretStoreError)
ChannelStore(ChannelStoreError)
StateStore(StateStoreError)
Transport(TransportValidationError)
InvalidInput(&'static str)
ProtobufDecode(DecodeError)
ProtobufEncode(EncodeError)
Invariant(&'static str)
RoleMismatch
ChannelAlreadyPaired
start(Pairing) was called for a channel_id that already has
a Paired channel record. Re-pairing would silently overwrite
the stored SharedKey; the caller must skip the call or unpair
first.
ReplicaIdNotConfigured
A replica-mode flow was attempted but the protocol was built without
DeRecProtocolBuilder::with_replica_id.
Surfaces at the entry points of every flow that requires a local
replica identity (initiating a replica-mode pairing, handling an
inbound PairRequest whose sender_kind is ReplicaSource or
ReplicaDestination, etc.).
Implementations